#
import os
import threading
import tempita
import webob
import selector
import formencode

environments = threading.local()
def get_environ():
    if hasattr(environments, 'environ'):
        return environments.environ
    else:
        return webob.Request.blank('').environ


def set_thread_environ(environ):
    environments.environ = environ


request = webob.Request(environ_getter=get_environ)

application = selector.Selector()

def weboblize(func):
    def decorator(environ, start_response):
        set_thread_environ(environ)
        url_vars = environ.get('wsgiorg.routing_args', [[], {}])
        res = func(*url_vars[0], **url_vars[1])
        return res(environ, start_response)
    return decorator 

def expose(pattern, method='GET', auth=False):
    def wrap(func):
        newfunc = weboblize(func)
        application.add(pattern, **{method:newfunc})
        newfunc.basefunc = func
        return newfunc
    return wrap

def validate(validator, error_handler):
    def wrap(func):
        def decorator(*args, **kwargs):
            try:
                params = validator.to_python(request.params)
                request.environ['form_result'] = params
                return func(*args, **kwargs)
            except formencode.Invalid, e:
                return error_handler.basefunc(errors=e.error_dict)
        return decorator
    return wrap

class Renderer(object):
    def __init__(self):
        self.templatedir = os.getcwd()
        self.templateValues = dict(request=request)

    def render(self, template, **kwargs):
        res = webob.Response()
        tmpl = tempita.HTMLTemplate.from_filename(os.path.join(self.templatedir, template))
        kwargs = kwargs.copy()
        kwargs.update(self.templateValues)
        res.body = tmpl.substitute(**kwargs)
        return res

renderer = Renderer()




from setuptools import setup, find_packages
try:
    import buildutils
except ImportError:
    pass
import sys, os

version = '0.1.1'

setup(name='pocketwsgi',
      version=version,
      description="tiny wsgi application framework",
      long_description="""\
""",
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='wsgi',
      author='Atsushi Odagiri',
      author_email='aodagx@gmail.com',
      url='http://aodagx.ddo.jp/aodag/projects/pocketwsgi',
      license='',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
        # -*- Extra requirements: -*-
        'Tempita',
        'WebOb',
        'selector',
        'FormEncode',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )
